<?php 

if(!( function_exists( 'ebor_header_section' ) )){
	function ebor_header_section( $title = false, $subtitle = false ){
		
		$output = '<section class="white"><div class="container clearfix"><div class="col-md-7 col-md-offset-1">';
		
		if( $title ){
			$output .= '<p class="large">'. wp_kses_post( $title ) .'</p>';
		}
		
		if( $subtitle ){
			$output .= '<h1 class="header">'. wp_kses_post( $subtitle ) .'</h1>';
		}

		$output .= '</div></div></section>';
		
		return apply_filters( 'ebor_header_section', $output );
		
	}
}

/**
 * Blog pagination
 */
if(!( function_exists('ebor_pagination') )){
	function ebor_pagination($pages = '', $range = 2){
		$showitems = ($range * 2)+1;
		
		global $paged;
		if(empty($paged)) $paged = 1;
		
		if($pages == ''){
			global $wp_query;
			$pages = $wp_query->max_num_pages;
				if(!$pages) {
					$pages = 1;
				}
		}
		
		$output = '';
		
		if(1 != $pages){
			
			$output .= '<ul class="pagination clearfix">';
			if($paged > 2 && $paged > $range+1 && $showitems < $pages) $output .= "<a href='".get_pagenum_link(1)."'><i class=\"fa fa-angle-left\"></i></a>";
			
			for ($i=1; $i <= $pages; $i++){
				if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )){
					$output .= ($paged == $i)? "<li><a href=\"#\" class=\"active\">".$i."</a></li>":"<li><a href='".get_pagenum_link($i)."'>".$i."</a></li>";
				}
			}
		
			if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) $output .= "<a href='".get_pagenum_link($pages)."'><i class=\"fa fa-angle-right\"></i></a>";
			$output.= "</ul>";
		}
		
		return $output;
	}
}

/**
 * ebor_get_footer_layout
 * 
 * Use to conditionally check the page footer meta layout against the theme option for the same
 * In short, this function can override the global footer option on a post by post basis
 * Call within get_footer() for this to override the global footer choice
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_get_footer_layout' ) )){
	function ebor_get_footer_layout( $post_id = false ){
		
		if( false == $post_id ){
			
			global $post;
			
			if( isset( $post->ID ) ){
				$post_id = $post->ID;
			}
			
		}
		
		if(!( isset( $post_id ) ))
			return get_option( 'footer_layout', '1' );
		
		$footer = get_post_meta( $post_id, '_ebor_footer_override', 1 );
		if( '' == $footer || false == $footer || 'none' == $footer ){
			$footer = get_option( 'footer_layout', '1' );
		}
		
		return $footer;	
		
	}
}

/**
 * ebor_get_header_layout
 * 
 * Use to conditionally check the page header meta layout against the theme option for the same
 * In short, this function can override the global header option on a post by post basis
 * Call within get_header() for this to override the global header choice
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_get_header_layout' ) )){
	function ebor_get_header_layout( $post_id = false ){
		
		if( false == $post_id ){
			
			global $post;
			
			if( isset( $post->ID ) ){
				$post_id = $post->ID;
			}
			
		}
		
		if( is_search() || !( isset( $post_id ) ) )
			return get_option( 'header_layout', '1' );
		
		$header = get_post_meta( $post_id, '_ebor_header_override', 1 );
		if( '' == $header || false == $header || 'none' == $header ){
			$header = get_option( 'header_layout', '1' );
		}
		
		return $header;	
		
	}
}

/**
 * Init theme options
 * Certain theme options need to be written to the database as soon as the theme is installed.
 * This is either for the enqueues in ebor-framework, or to override the default image sizes in WooCommerce.
 * Either way this function is only called when the theme is first activated, de-activating and re-activating the theme will result in these options returning to defaults.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_init_theme_options') )){
	
	/**
	 * Hook in on activation
	 */
	global $pagenow;
	
	/**
	 * Define image sizes
	 */
	function ebor_init_theme_options() {
		
		//Set all options to zero before initialising options for this theme
		$existing_options = get_option('ebor_framework_options');
		if( is_array($existing_options) ){
			foreach ($existing_options as $key => $value) {
				$existing_options[$key] = '0';
			}
			update_option('ebor_framework_options', $existing_options);
		}
		
		//Ebor Framework
		$framework_args = array(
			'portfolio_post_type'   => '1',
			'team_post_type'        => '1',
			'options'               => '1',
			'belton_vc_shortcodes'  => '1'
		);
		update_option('ebor_framework_options', $framework_args);
		
	}
	
	/**
	 * Only call this action when we first activate the theme.
	 */
	if ( 
		is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ||
		is_admin() && isset( $_GET['theme'] ) && $pagenow == 'customize.php'
	){
		add_action( 'after_setup_theme', 'ebor_init_theme_options', 1 );
	}
	
}

/**
 * Register the required plugins for this theme.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_register_required_plugins') )){
	function ebor_register_required_plugins() {
		$plugins = array(
			array(
			    'name'      => esc_html__( 'Contact Form 7', 'belton' ),
			    'slug'      => 'contact-form-7',
			    'required'  => false,
			    'version' 	=> '3.7.2'
			),
			array(
			    'name'      => esc_html__( 'Custom Metaboxes 2', 'belton' ),
			    'slug'      => 'cmb2',
			    'required'  => true,
			    'version' 	=> '1.0.0'
			),
			array(
			    'name'      => esc_html__( 'One Click Demo Import', 'belton' ),
			    'slug'      => 'one-click-demo-import',
			    'required'  => false,
			    'version' 	=> '1.0.0'
			),
			array(
				'name'     				=> esc_html__( 'Ebor Framework', 'belton' ),
				'slug'     				=> 'Ebor-Framework-master',
				'source'   				=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
				'required' 				=> true,
				'version' 				=> '1.4.4',
				'external_url' 			=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
			),
			array(
				'name'     				=> esc_html__( 'WPBakery Page Builder', 'belton' ),
				'slug'     				=> 'js_composer',
				'source'   				=> 'http://www.madeinebor.com/plugin-downloads/js_composer-latest.zip',
				'required' 				=> false,
				'external_url' 			=> 'http://www.madeinebor.com/plugin-downloads/js_composer-latest.zip',
				'version' 				=> '5.4.2',
			)
		);
		$config = array(
			'is_automatic' => true,
		);
		tgmpa( $plugins, $config );
	}
	add_action( 'tgmpa_register', 'ebor_register_required_plugins' );
}

if(!( function_exists('ebor_get_icons') )){
	function ebor_get_icons(){
		return array('fa-500px' => '500px','fa-address-book' => 'Address Book','fa-address-book-o' => 'Address Book O','fa-address-card' => 'Address Card','fa-address-card-o' => 'Address Card O','fa-adjust' => 'Adjust','fa-adn' => 'Adn','fa-align-center' => 'Align Center','fa-align-justify' => 'Align Justify','fa-align-left' => 'Align Left','fa-align-right' => 'Align Right','fa-amazon' => 'Amazon','fa-ambulance' => 'Ambulance','fa-american-sign-language-interpreting' => 'American Sign Language Interpreting','fa-anchor' => 'Anchor','fa-android' => 'Android','fa-angellist' => 'Angellist','fa-angle-double-down' => 'Angle Double Down','fa-angle-double-left' => 'Angle Double Left','fa-angle-double-right' => 'Angle Double Right','fa-angle-double-up' => 'Angle Double Up','fa-angle-down' => 'Angle Down','fa-angle-left' => 'Angle Left','fa-angle-right' => 'Angle Right','fa-angle-up' => 'Angle Up','fa-apple' => 'Apple','fa-archive' => 'Archive','fa-area-chart' => 'Area Chart','fa-arrow-circle-down' => 'Arrow Circle Down','fa-arrow-circle-left' => 'Arrow Circle Left','fa-arrow-circle-o-down' => 'Arrow Circle O Down','fa-arrow-circle-o-left' => 'Arrow Circle O Left','fa-arrow-circle-o-right' => 'Arrow Circle O Right','fa-arrow-circle-o-up' => 'Arrow Circle O Up','fa-arrow-circle-right' => 'Arrow Circle Right','fa-arrow-circle-up' => 'Arrow Circle Up','fa-arrow-down' => 'Arrow Down','fa-arrow-left' => 'Arrow Left','fa-arrow-right' => 'Arrow Right','fa-arrow-up' => 'Arrow Up','fa-arrows' => 'Arrows','fa-arrows-alt' => 'Arrows Alt','fa-arrows-h' => 'Arrows H','fa-arrows-v' => 'Arrows V','fa-asl-interpreting' => 'Asl Interpreting','fa-assistive-listening-systems' => 'Assistive Listening Systems','fa-asterisk' => 'Asterisk','fa-at' => 'At','fa-audio-description' => 'Audio Description','fa-automobile' => 'Automobile','fa-backward' => 'Backward','fa-balance-scale' => 'Balance Scale','fa-ban' => 'Ban','fa-bandcamp' => 'Bandcamp','fa-bank' => 'Bank','fa-bar-chart' => 'Bar Chart','fa-bar-chart-o' => 'Bar Chart O','fa-barcode' => 'Barcode','fa-bars' => 'Bars','fa-bath' => 'Bath','fa-bathtub' => 'Bathtub','fa-battery' => 'Battery','fa-battery-0' => 'Battery 0','fa-battery-1' => 'Battery 1','fa-battery-2' => 'Battery 2','fa-battery-3' => 'Battery 3','fa-battery-4' => 'Battery 4','fa-battery-empty' => 'Battery Empty','fa-battery-full' => 'Battery Full','fa-battery-half' => 'Battery Half','fa-battery-quarter' => 'Battery Quarter','fa-battery-three-quarters' => 'Battery Three Quarters','fa-bed' => 'Bed','fa-beer' => 'Beer','fa-behance' => 'Behance','fa-behance-square' => 'Behance Square','fa-bell' => 'Bell','fa-bell-o' => 'Bell O','fa-bell-slash' => 'Bell Slash','fa-bell-slash-o' => 'Bell Slash O','fa-bicycle' => 'Bicycle','fa-binoculars' => 'Binoculars','fa-birthday-cake' => 'Birthday Cake','fa-bitbucket' => 'Bitbucket','fa-bitbucket-square' => 'Bitbucket Square','fa-bitcoin' => 'Bitcoin','fa-black-tie' => 'Black Tie','fa-blind' => 'Blind','fa-bluetooth' => 'Bluetooth','fa-bluetooth-b' => 'Bluetooth B','fa-bold' => 'Bold','fa-bolt' => 'Bolt','fa-bomb' => 'Bomb','fa-book' => 'Book','fa-bookmark' => 'Bookmark','fa-bookmark-o' => 'Bookmark O','fa-braille' => 'Braille','fa-briefcase' => 'Briefcase','fa-btc' => 'Btc','fa-bug' => 'Bug','fa-building' => 'Building','fa-building-o' => 'Building O','fa-bullhorn' => 'Bullhorn','fa-bullseye' => 'Bullseye','fa-bus' => 'Bus','fa-buysellads' => 'Buysellads','fa-cab' => 'Cab','fa-calculator' => 'Calculator','fa-calendar' => 'Calendar','fa-calendar-check-o' => 'Calendar Check O','fa-calendar-minus-o' => 'Calendar Minus O','fa-calendar-o' => 'Calendar O','fa-calendar-plus-o' => 'Calendar Plus O','fa-calendar-times-o' => 'Calendar Times O','fa-camera' => 'Camera','fa-camera-retro' => 'Camera Retro','fa-car' => 'Car','fa-caret-down' => 'Caret Down','fa-caret-left' => 'Caret Left','fa-caret-right' => 'Caret Right','fa-caret-square-o-down' => 'Caret Square O Down','fa-caret-square-o-left' => 'Caret Square O Left','fa-caret-square-o-right' => 'Caret Square O Right','fa-caret-square-o-up' => 'Caret Square O Up','fa-caret-up' => 'Caret Up','fa-cart-arrow-down' => 'Cart Arrow Down','fa-cart-plus' => 'Cart Plus','fa-cc' => 'Cc','fa-cc-amex' => 'Cc Amex','fa-cc-diners-club' => 'Cc Diners Club','fa-cc-discover' => 'Cc Discover','fa-cc-jcb' => 'Cc Jcb','fa-cc-mastercard' => 'Cc Mastercard','fa-cc-paypal' => 'Cc Paypal','fa-cc-stripe' => 'Cc Stripe','fa-cc-visa' => 'Cc Visa','fa-certificate' => 'Certificate','fa-chain' => 'Chain','fa-chain-broken' => 'Chain Broken','fa-check' => 'Check','fa-check-circle' => 'Check Circle','fa-check-circle-o' => 'Check Circle O','fa-check-square' => 'Check Square','fa-check-square-o' => 'Check Square O','fa-chevron-circle-down' => 'Chevron Circle Down','fa-chevron-circle-left' => 'Chevron Circle Left','fa-chevron-circle-right' => 'Chevron Circle Right','fa-chevron-circle-up' => 'Chevron Circle Up','fa-chevron-down' => 'Chevron Down','fa-chevron-left' => 'Chevron Left','fa-chevron-right' => 'Chevron Right','fa-chevron-up' => 'Chevron Up','fa-child' => 'Child','fa-chrome' => 'Chrome','fa-circle' => 'Circle','fa-circle-o' => 'Circle O','fa-circle-o-notch' => 'Circle O Notch','fa-circle-thin' => 'Circle Thin','fa-clipboard' => 'Clipboard','fa-clock-o' => 'Clock O','fa-clone' => 'Clone','fa-close' => 'Close','fa-cloud' => 'Cloud','fa-cloud-download' => 'Cloud Download','fa-cloud-upload' => 'Cloud Upload','fa-cny' => 'Cny','fa-code' => 'Code','fa-code-fork' => 'Code Fork','fa-codepen' => 'Codepen','fa-codiepie' => 'Codiepie','fa-coffee' => 'Coffee','fa-cog' => 'Cog','fa-cogs' => 'Cogs','fa-columns' => 'Columns','fa-comment' => 'Comment','fa-comment-o' => 'Comment O','fa-commenting' => 'Commenting','fa-commenting-o' => 'Commenting O','fa-comments' => 'Comments','fa-comments-o' => 'Comments O','fa-compass' => 'Compass','fa-compress' => 'Compress','fa-connectdevelop' => 'Connectdevelop','fa-contao' => 'Contao','fa-copy' => 'Copy','fa-copyright' => 'Copyright','fa-creative-commons' => 'Creative Commons','fa-credit-card' => 'Credit Card','fa-credit-card-alt' => 'Credit Card Alt','fa-crop' => 'Crop','fa-crosshairs' => 'Crosshairs','fa-css3' => 'Css3','fa-cube' => 'Cube','fa-cubes' => 'Cubes','fa-cut' => 'Cut','fa-cutlery' => 'Cutlery','fa-dashboard' => 'Dashboard','fa-dashcube' => 'Dashcube','fa-database' => 'Database','fa-deaf' => 'Deaf','fa-deafness' => 'Deafness','fa-dedent' => 'Dedent','fa-delicious' => 'Delicious','fa-desktop' => 'Desktop','fa-deviantart' => 'Deviantart','fa-diamond' => 'Diamond','fa-digg' => 'Digg','fa-dollar' => 'Dollar','fa-dot-circle-o' => 'Dot Circle O','fa-download' => 'Download','fa-dribbble' => 'Dribbble','fa-drivers-license' => 'Drivers License','fa-drivers-license-o' => 'Drivers License O','fa-dropbox' => 'Dropbox','fa-drupal' => 'Drupal','fa-edge' => 'Edge','fa-edit' => 'Edit','fa-eercast' => 'Eercast','fa-eject' => 'Eject','fa-ellipsis-h' => 'Ellipsis H','fa-ellipsis-v' => 'Ellipsis V','fa-empire' => 'Empire','fa-envelope' => 'Envelope','fa-envelope-o' => 'Envelope O','fa-envelope-open' => 'Envelope Open','fa-envelope-open-o' => 'Envelope Open O','fa-envelope-square' => 'Envelope Square','fa-envira' => 'Envira','fa-eraser' => 'Eraser','fa-etsy' => 'Etsy','fa-eur' => 'Eur','fa-euro' => 'Euro','fa-exchange' => 'Exchange','fa-exclamation' => 'Exclamation','fa-exclamation-circle' => 'Exclamation Circle','fa-exclamation-triangle' => 'Exclamation Triangle','fa-expand' => 'Expand','fa-expeditedssl' => 'Expeditedssl','fa-external-link' => 'External Link','fa-external-link-square' => 'External Link Square','fa-eye' => 'Eye','fa-eye-slash' => 'Eye Slash','fa-eyedropper' => 'Eyedropper','fa-fa' => 'Fa','fa-facebook' => 'Facebook','fa-facebook-f' => 'Facebook F','fa-facebook-official' => 'Facebook Official','fa-facebook-square' => 'Facebook Square','fa-fast-backward' => 'Fast Backward','fa-fast-forward' => 'Fast Forward','fa-fax' => 'Fax','fa-feed' => 'Feed','fa-female' => 'Female','fa-fighter-jet' => 'Fighter Jet','fa-file' => 'File','fa-file-archive-o' => 'File Archive O','fa-file-audio-o' => 'File Audio O','fa-file-code-o' => 'File Code O','fa-file-excel-o' => 'File Excel O','fa-file-image-o' => 'File Image O','fa-file-movie-o' => 'File Movie O','fa-file-o' => 'File O','fa-file-pdf-o' => 'File Pdf O','fa-file-photo-o' => 'File Photo O','fa-file-picture-o' => 'File Picture O','fa-file-powerpoint-o' => 'File Powerpoint O','fa-file-sound-o' => 'File Sound O','fa-file-text' => 'File Text','fa-file-text-o' => 'File Text O','fa-file-video-o' => 'File Video O','fa-file-word-o' => 'File Word O','fa-file-zip-o' => 'File Zip O','fa-files-o' => 'Files O','fa-film' => 'Film','fa-filter' => 'Filter','fa-fire' => 'Fire','fa-fire-extinguisher' => 'Fire Extinguisher','fa-firefox' => 'Firefox','fa-first-order' => 'First Order','fa-flag' => 'Flag','fa-flag-checkered' => 'Flag Checkered','fa-flag-o' => 'Flag O','fa-flash' => 'Flash','fa-flask' => 'Flask','fa-flickr' => 'Flickr','fa-floppy-o' => 'Floppy O','fa-folder' => 'Folder','fa-folder-o' => 'Folder O','fa-folder-open' => 'Folder Open','fa-folder-open-o' => 'Folder Open O','fa-font' => 'Font','fa-font-awesome' => 'Font Awesome','fa-fonticons' => 'Fonticons','fa-fort-awesome' => 'Fort Awesome','fa-forumbee' => 'Forumbee','fa-forward' => 'Forward','fa-foursquare' => 'Foursquare','fa-free-code-camp' => 'Free Code Camp','fa-frown-o' => 'Frown O','fa-futbol-o' => 'Futbol O','fa-gamepad' => 'Gamepad','fa-gavel' => 'Gavel','fa-gbp' => 'Gbp','fa-ge' => 'Ge','fa-gear' => 'Gear','fa-gears' => 'Gears','fa-genderless' => 'Genderless','fa-get-pocket' => 'Get Pocket','fa-gg' => 'Gg','fa-gg-circle' => 'Gg Circle','fa-gift' => 'Gift','fa-git' => 'Git','fa-git-square' => 'Git Square','fa-github' => 'Github','fa-github-alt' => 'Github Alt','fa-github-square' => 'Github Square','fa-gitlab' => 'Gitlab','fa-gittip' => 'Gittip','fa-glass' => 'Glass','fa-glide' => 'Glide','fa-glide-g' => 'Glide G','fa-globe' => 'Globe','fa-google' => 'Google','fa-google-plus' => 'Google Plus','fa-google-plus-circle' => 'Google Plus Circle','fa-google-plus-official' => 'Google Plus Official','fa-google-plus-square' => 'Google Plus Square','fa-google-wallet' => 'Google Wallet','fa-graduation-cap' => 'Graduation Cap','fa-gratipay' => 'Gratipay','fa-grav' => 'Grav','fa-group' => 'Group','fa-h-square' => 'H Square','fa-hacker-news' => 'Hacker News','fa-hand-grab-o' => 'Hand Grab O','fa-hand-lizard-o' => 'Hand Lizard O','fa-hand-o-down' => 'Hand O Down','fa-hand-o-left' => 'Hand O Left','fa-hand-o-right' => 'Hand O Right','fa-hand-o-up' => 'Hand O Up','fa-hand-paper-o' => 'Hand Paper O','fa-hand-peace-o' => 'Hand Peace O','fa-hand-pointer-o' => 'Hand Pointer O','fa-hand-rock-o' => 'Hand Rock O','fa-hand-scissors-o' => 'Hand Scissors O','fa-hand-spock-o' => 'Hand Spock O','fa-hand-stop-o' => 'Hand Stop O','fa-handshake-o' => 'Handshake O','fa-hard-of-hearing' => 'Hard Of Hearing','fa-hashtag' => 'Hashtag','fa-hdd-o' => 'Hdd O','fa-header' => 'Header','fa-headphones' => 'Headphones','fa-heart' => 'Heart','fa-heart-o' => 'Heart O','fa-heartbeat' => 'Heartbeat','fa-history' => 'History','fa-home' => 'Home','fa-hospital-o' => 'Hospital O','fa-hotel' => 'Hotel','fa-hourglass' => 'Hourglass','fa-hourglass-1' => 'Hourglass 1','fa-hourglass-2' => 'Hourglass 2','fa-hourglass-3' => 'Hourglass 3','fa-hourglass-end' => 'Hourglass End','fa-hourglass-half' => 'Hourglass Half','fa-hourglass-o' => 'Hourglass O','fa-hourglass-start' => 'Hourglass Start','fa-houzz' => 'Houzz','fa-html5' => 'Html5','fa-i-cursor' => 'I Cursor','fa-id-badge' => 'Id Badge','fa-id-card' => 'Id Card','fa-id-card-o' => 'Id Card O','fa-ils' => 'Ils','fa-image' => 'Image','fa-imdb' => 'Imdb','fa-inbox' => 'Inbox','fa-indent' => 'Indent','fa-industry' => 'Industry','fa-info' => 'Info','fa-info-circle' => 'Info Circle','fa-inr' => 'Inr','fa-instagram' => 'Instagram','fa-institution' => 'Institution','fa-internet-explorer' => 'Internet Explorer','fa-intersex' => 'Intersex','fa-ioxhost' => 'Ioxhost','fa-italic' => 'Italic','fa-joomla' => 'Joomla','fa-jpy' => 'Jpy','fa-jsfiddle' => 'Jsfiddle','fa-key' => 'Key','fa-keyboard-o' => 'Keyboard O','fa-krw' => 'Krw','fa-language' => 'Language','fa-laptop' => 'Laptop','fa-lastfm' => 'Lastfm','fa-lastfm-square' => 'Lastfm Square','fa-leaf' => 'Leaf','fa-leanpub' => 'Leanpub','fa-legal' => 'Legal','fa-lemon-o' => 'Lemon O','fa-level-down' => 'Level Down','fa-level-up' => 'Level Up','fa-life-bouy' => 'Life Bouy','fa-life-buoy' => 'Life Buoy','fa-life-ring' => 'Life Ring','fa-life-saver' => 'Life Saver','fa-lightbulb-o' => 'Lightbulb O','fa-line-chart' => 'Line Chart','fa-link' => 'Link','fa-linkedin' => 'Linkedin','fa-linkedin-square' => 'Linkedin Square','fa-linode' => 'Linode','fa-linux' => 'Linux','fa-list' => 'List','fa-list-alt' => 'List Alt','fa-list-ol' => 'List Ol','fa-list-ul' => 'List Ul','fa-location-arrow' => 'Location Arrow','fa-lock' => 'Lock','fa-long-arrow-down' => 'Long Arrow Down','fa-long-arrow-left' => 'Long Arrow Left','fa-long-arrow-right' => 'Long Arrow Right','fa-long-arrow-up' => 'Long Arrow Up','fa-low-vision' => 'Low Vision','fa-magic' => 'Magic','fa-magnet' => 'Magnet','fa-mail-forward' => 'Mail Forward','fa-mail-reply' => 'Mail Reply','fa-mail-reply-all' => 'Mail Reply All','fa-male' => 'Male','fa-map' => 'Map','fa-map-marker' => 'Map Marker','fa-map-o' => 'Map O','fa-map-pin' => 'Map Pin','fa-map-signs' => 'Map Signs','fa-mars' => 'Mars','fa-mars-double' => 'Mars Double','fa-mars-stroke' => 'Mars Stroke','fa-mars-stroke-h' => 'Mars Stroke H','fa-mars-stroke-v' => 'Mars Stroke V','fa-maxcdn' => 'Maxcdn','fa-meanpath' => 'Meanpath','fa-medium' => 'Medium','fa-medkit' => 'Medkit','fa-meetup' => 'Meetup','fa-meh-o' => 'Meh O','fa-mercury' => 'Mercury','fa-microchip' => 'Microchip','fa-microphone' => 'Microphone','fa-microphone-slash' => 'Microphone Slash','fa-minus' => 'Minus','fa-minus-circle' => 'Minus Circle','fa-minus-square' => 'Minus Square','fa-minus-square-o' => 'Minus Square O','fa-mixcloud' => 'Mixcloud','fa-mobile' => 'Mobile','fa-mobile-phone' => 'Mobile Phone','fa-modx' => 'Modx','fa-money' => 'Money','fa-moon-o' => 'Moon O','fa-mortar-board' => 'Mortar Board','fa-motorcycle' => 'Motorcycle','fa-mouse-pointer' => 'Mouse Pointer','fa-music' => 'Music','fa-navicon' => 'Navicon','fa-neuter' => 'Neuter','fa-newspaper-o' => 'Newspaper O','fa-object-group' => 'Object Group','fa-object-ungroup' => 'Object Ungroup','fa-odnoklassniki' => 'Odnoklassniki','fa-odnoklassniki-square' => 'Odnoklassniki Square','fa-opencart' => 'Opencart','fa-openid' => 'Openid','fa-opera' => 'Opera','fa-optin-monster' => 'Optin Monster','fa-outdent' => 'Outdent','fa-pagelines' => 'Pagelines','fa-paint-brush' => 'Paint Brush','fa-paper-plane' => 'Paper Plane','fa-paper-plane-o' => 'Paper Plane O','fa-paperclip' => 'Paperclip','fa-paragraph' => 'Paragraph','fa-paste' => 'Paste','fa-pause' => 'Pause','fa-pause-circle' => 'Pause Circle','fa-pause-circle-o' => 'Pause Circle O','fa-paw' => 'Paw','fa-paypal' => 'Paypal','fa-pencil' => 'Pencil','fa-pencil-square' => 'Pencil Square','fa-pencil-square-o' => 'Pencil Square O','fa-percent' => 'Percent','fa-phone' => 'Phone','fa-phone-square' => 'Phone Square','fa-photo' => 'Photo','fa-picture-o' => 'Picture O','fa-pie-chart' => 'Pie Chart','fa-pied-piper' => 'Pied Piper','fa-pied-piper-alt' => 'Pied Piper Alt','fa-pied-piper-pp' => 'Pied Piper Pp','fa-pinterest' => 'Pinterest','fa-pinterest-p' => 'Pinterest P','fa-pinterest-square' => 'Pinterest Square','fa-plane' => 'Plane','fa-play' => 'Play','fa-play-circle' => 'Play Circle','fa-play-circle-o' => 'Play Circle O','fa-plug' => 'Plug','fa-plus' => 'Plus','fa-plus-circle' => 'Plus Circle','fa-plus-square' => 'Plus Square','fa-plus-square-o' => 'Plus Square O','fa-podcast' => 'Podcast','fa-power-off' => 'Power Off','fa-print' => 'Print','fa-product-hunt' => 'Product Hunt','fa-puzzle-piece' => 'Puzzle Piece','fa-qq' => 'Qq','fa-qrcode' => 'Qrcode','fa-question' => 'Question','fa-question-circle' => 'Question Circle','fa-question-circle-o' => 'Question Circle O','fa-quora' => 'Quora','fa-quote-left' => 'Quote Left','fa-quote-right' => 'Quote Right','fa-ra' => 'Ra','fa-random' => 'Random','fa-ravelry' => 'Ravelry','fa-rebel' => 'Rebel','fa-recycle' => 'Recycle','fa-reddit' => 'Reddit','fa-reddit-alien' => 'Reddit Alien','fa-reddit-square' => 'Reddit Square','fa-refresh' => 'Refresh','fa-registered' => 'Registered','fa-remove' => 'Remove','fa-renren' => 'Renren','fa-reorder' => 'Reorder','fa-repeat' => 'Repeat','fa-reply' => 'Reply','fa-reply-all' => 'Reply All','fa-resistance' => 'Resistance','fa-retweet' => 'Retweet','fa-rmb' => 'Rmb','fa-road' => 'Road','fa-rocket' => 'Rocket','fa-rotate-left' => 'Rotate Left','fa-rotate-right' => 'Rotate Right','fa-rouble' => 'Rouble','fa-rss' => 'Rss','fa-rss-square' => 'Rss Square','fa-rub' => 'Rub','fa-ruble' => 'Ruble','fa-rupee' => 'Rupee','fa-s15' => 'S15','fa-safari' => 'Safari','fa-save' => 'Save','fa-scissors' => 'Scissors','fa-scribd' => 'Scribd','fa-search' => 'Search','fa-search-minus' => 'Search Minus','fa-search-plus' => 'Search Plus','fa-sellsy' => 'Sellsy','fa-send' => 'Send','fa-send-o' => 'Send O','fa-server' => 'Server','fa-share' => 'Share','fa-share-alt' => 'Share Alt','fa-share-alt-square' => 'Share Alt Square','fa-share-square' => 'Share Square','fa-share-square-o' => 'Share Square O','fa-shekel' => 'Shekel','fa-sheqel' => 'Sheqel','fa-shield' => 'Shield','fa-ship' => 'Ship','fa-shirtsinbulk' => 'Shirtsinbulk','fa-shopping-bag' => 'Shopping Bag','fa-shopping-basket' => 'Shopping Basket','fa-shopping-cart' => 'Shopping Cart','fa-shower' => 'Shower','fa-sign-in' => 'Sign In','fa-sign-language' => 'Sign Language','fa-sign-out' => 'Sign Out','fa-signal' => 'Signal','fa-signing' => 'Signing','fa-simplybuilt' => 'Simplybuilt','fa-sitemap' => 'Sitemap','fa-skyatlas' => 'Skyatlas','fa-skype' => 'Skype','fa-slack' => 'Slack','fa-sliders' => 'Sliders','fa-slideshare' => 'Slideshare','fa-smile-o' => 'Smile O','fa-snapchat' => 'Snapchat','fa-snapchat-ghost' => 'Snapchat Ghost','fa-snapchat-square' => 'Snapchat Square','fa-snowflake-o' => 'Snowflake O','fa-soccer-ball-o' => 'Soccer Ball O','fa-sort' => 'Sort','fa-sort-alpha-asc' => 'Sort Alpha Asc','fa-sort-alpha-desc' => 'Sort Alpha Desc','fa-sort-amount-asc' => 'Sort Amount Asc','fa-sort-amount-desc' => 'Sort Amount Desc','fa-sort-asc' => 'Sort Asc','fa-sort-desc' => 'Sort Desc','fa-sort-down' => 'Sort Down','fa-sort-numeric-asc' => 'Sort Numeric Asc','fa-sort-numeric-desc' => 'Sort Numeric Desc','fa-sort-up' => 'Sort Up','fa-soundcloud' => 'Soundcloud','fa-space-shuttle' => 'Space Shuttle','fa-spinner' => 'Spinner','fa-spoon' => 'Spoon','fa-spotify' => 'Spotify','fa-square' => 'Square','fa-square-o' => 'Square O','fa-stack-exchange' => 'Stack Exchange','fa-stack-overflow' => 'Stack Overflow','fa-star' => 'Star','fa-star-half' => 'Star Half','fa-star-half-empty' => 'Star Half Empty','fa-star-half-full' => 'Star Half Full','fa-star-half-o' => 'Star Half O','fa-star-o' => 'Star O','fa-steam' => 'Steam','fa-steam-square' => 'Steam Square','fa-step-backward' => 'Step Backward','fa-step-forward' => 'Step Forward','fa-stethoscope' => 'Stethoscope','fa-sticky-note' => 'Sticky Note','fa-sticky-note-o' => 'Sticky Note O','fa-stop' => 'Stop','fa-stop-circle' => 'Stop Circle','fa-stop-circle-o' => 'Stop Circle O','fa-street-view' => 'Street View','fa-strikethrough' => 'Strikethrough','fa-stumbleupon' => 'Stumbleupon','fa-stumbleupon-circle' => 'Stumbleupon Circle','fa-subscript' => 'Subscript','fa-subway' => 'Subway','fa-suitcase' => 'Suitcase','fa-sun-o' => 'Sun O','fa-superpowers' => 'Superpowers','fa-superscript' => 'Superscript','fa-support' => 'Support','fa-table' => 'Table','fa-tablet' => 'Tablet','fa-tachometer' => 'Tachometer','fa-tag' => 'Tag','fa-tags' => 'Tags','fa-tasks' => 'Tasks','fa-taxi' => 'Taxi','fa-telegram' => 'Telegram','fa-television' => 'Television','fa-tencent-weibo' => 'Tencent Weibo','fa-terminal' => 'Terminal','fa-text-height' => 'Text Height','fa-text-width' => 'Text Width','fa-th' => 'Th','fa-th-large' => 'Th Large','fa-th-list' => 'Th List','fa-themeisle' => 'Themeisle','fa-thermometer' => 'Thermometer','fa-thermometer-0' => 'Thermometer 0','fa-thermometer-1' => 'Thermometer 1','fa-thermometer-2' => 'Thermometer 2','fa-thermometer-3' => 'Thermometer 3','fa-thermometer-4' => 'Thermometer 4','fa-thermometer-empty' => 'Thermometer Empty','fa-thermometer-full' => 'Thermometer Full','fa-thermometer-half' => 'Thermometer Half','fa-thermometer-quarter' => 'Thermometer Quarter','fa-thermometer-three-quarters' => 'Thermometer Three Quarters','fa-thumb-tack' => 'Thumb Tack','fa-thumbs-down' => 'Thumbs Down','fa-thumbs-o-down' => 'Thumbs O Down','fa-thumbs-o-up' => 'Thumbs O Up','fa-thumbs-up' => 'Thumbs Up','fa-ticket' => 'Ticket','fa-times' => 'Times','fa-times-circle' => 'Times Circle','fa-times-circle-o' => 'Times Circle O','fa-times-rectangle' => 'Times Rectangle','fa-times-rectangle-o' => 'Times Rectangle O','fa-tint' => 'Tint','fa-toggle-down' => 'Toggle Down','fa-toggle-left' => 'Toggle Left','fa-toggle-off' => 'Toggle Off','fa-toggle-on' => 'Toggle On','fa-toggle-right' => 'Toggle Right','fa-toggle-up' => 'Toggle Up','fa-trademark' => 'Trademark','fa-train' => 'Train','fa-transgender' => 'Transgender','fa-transgender-alt' => 'Transgender Alt','fa-trash' => 'Trash','fa-trash-o' => 'Trash O','fa-tree' => 'Tree','fa-trello' => 'Trello','fa-tripadvisor' => 'Tripadvisor','fa-trophy' => 'Trophy','fa-truck' => 'Truck','fa-try' => 'Try','fa-tty' => 'Tty','fa-tumblr' => 'Tumblr','fa-tumblr-square' => 'Tumblr Square','fa-turkish-lira' => 'Turkish Lira','fa-tv' => 'Tv','fa-twitch' => 'Twitch','fa-twitter' => 'Twitter','fa-twitter-square' => 'Twitter Square','fa-umbrella' => 'Umbrella','fa-underline' => 'Underline','fa-undo' => 'Undo','fa-universal-access' => 'Universal Access','fa-university' => 'University','fa-unlink' => 'Unlink','fa-unlock' => 'Unlock','fa-unlock-alt' => 'Unlock Alt','fa-unsorted' => 'Unsorted','fa-upload' => 'Upload','fa-usb' => 'Usb','fa-usd' => 'Usd','fa-user' => 'User','fa-user-circle' => 'User Circle','fa-user-circle-o' => 'User Circle O','fa-user-md' => 'User Md','fa-user-o' => 'User O','fa-user-plus' => 'User Plus','fa-user-secret' => 'User Secret','fa-user-times' => 'User Times','fa-users' => 'Users','fa-vcard' => 'Vcard','fa-vcard-o' => 'Vcard O','fa-venus' => 'Venus','fa-venus-double' => 'Venus Double','fa-venus-mars' => 'Venus Mars','fa-viacoin' => 'Viacoin','fa-viadeo' => 'Viadeo','fa-viadeo-square' => 'Viadeo Square','fa-video-camera' => 'Video Camera','fa-vimeo' => 'Vimeo','fa-vimeo-square' => 'Vimeo Square','fa-vine' => 'Vine','fa-vk' => 'Vk','fa-volume-control-phone' => 'Volume Control Phone','fa-volume-down' => 'Volume Down','fa-volume-off' => 'Volume Off','fa-volume-up' => 'Volume Up','fa-warning' => 'Warning','fa-wechat' => 'Wechat','fa-weibo' => 'Weibo','fa-weixin' => 'Weixin','fa-whatsapp' => 'Whatsapp','fa-wheelchair' => 'Wheelchair','fa-wheelchair-alt' => 'Wheelchair Alt','fa-wifi' => 'Wifi','fa-wikipedia-w' => 'Wikipedia W','fa-window-close' => 'Window Close','fa-window-close-o' => 'Window Close O','fa-window-maximize' => 'Window Maximize','fa-window-minimize' => 'Window Minimize','fa-window-restore' => 'Window Restore','fa-windows' => 'Windows','fa-won' => 'Won','fa-wordpress' => 'Wordpress','fa-wpbeginner' => 'Wpbeginner','fa-wpexplorer' => 'Wpexplorer','fa-wpforms' => 'Wpforms','fa-wrench' => 'Wrench','fa-xing' => 'Xing','fa-xing-square' => 'Xing Square','fa-y-combinator' => 'Y Combinator','fa-y-combinator-square' => 'Y Combinator Square','fa-yahoo' => 'Yahoo','fa-yc' => 'Yc','fa-yc-square' => 'Yc Square','fa-yelp' => 'Yelp','fa-yen' => 'Yen','fa-yoast' => 'Yoast','fa-youtube' => 'Youtube','fa-youtube-play' => 'Youtube Play','fa-youtube-square' => 'Youtube Square');
	}
}

if(!( function_exists('ebor_get_social_icons') )){
	function ebor_get_social_icons(){
		return array('fa-behance','fa-dribbble','fa-facebook','fa-flickr','fa-github','fa-grooveshark','fa-houzz','fa-icloud','fa-instagram','fa-lastfm','fa-linkedin','fa-medium','fa-picasa','fa-pinterest','fa-rdio','fa-skype','fa-soundcloud','fa-spotify','fa-spotify-with-circle','fa-stumbleupon','fa-tripadvisor','fa-tumblr','fa-twitter','fa-vimeo','fa-vine','fa-vk','fa-vk-alternitive','fa-windows-store','fa-xing','fa-yelp','fa-youko','fa-youtube', 'fa-envelope');
	}
}

/**
 * Custom Comment Markup for belton
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_custom_comment') )){
	function ebor_custom_comment($comment, $args, $depth) { 
		$GLOBALS['comment'] = $comment; 
	?>

	<li <?php comment_class( 'comment clearfix' ); ?> id="comment-<?php comment_ID() ?>">
		<div class="comment-body">
			
			<div class="commenter-avatar">
				<?php 
					if( 'comment' == get_comment_type() )
						echo get_avatar( $comment->comment_author_email, 60, false, false, array( 'class' => 'comment-avatar' ) ); 
				?>
			</div>
			
			<div class="comment-content">
				
			  	<p class="details"><?php echo get_comment_date(); ?><span class="alignright"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span></p>

			  	<h5><?php echo get_comment_author_link(); ?></h5>
				<?php echo wpautop( get_comment_text() ); ?>
				<?php if ($comment->comment_approved == '0') : ?>
					<p><em><?php esc_html_e('Your comment is awaiting moderation.', 'belton') ?></em></p>
				<?php endif; ?>
				
			</div>
			
		</div>
	
	<?php }
}

/**
 * Portfolio taxonomy terms output.
 *
 * Checks that terms exist in the portfolio-category taxonomy, then returns a comma seperated string of results.
 * @todo Allow for taxonomy input for differing taxonmoies through the same function.
 * @since 1.0.0
 * @return string
 */
if(!( function_exists('ebor_the_terms') )){
	function ebor_the_terms( $cat, $sep, $value, $args = array() ) {
		
		global $post;
		
		$terms = get_the_terms($post->ID, $cat, '', $sep, '');
		
		if( is_array($terms) ) {
			foreach( $terms as $term ){
				$args[] = $value;	
			}
			$terms = array_map('ebor_simple_cb', $terms, $args);
			return implode( $sep, $terms);
		}
		
	}
}
/**
 * Term name return
 *
 * Returns the Pretty Name of a term array
 * @param $t - the term array object
 * @since 1.0.0
 * @return string
 */
if(!( function_exists('ebor_simple_cb') )){
	function ebor_simple_cb($t, $v) { 
		if( 'slug' == $v ){
			return $t->slug;
		} elseif( 'link' == $v ){
			return '<a href="'.get_term_link( $t, 'portfolio_category' ).'">'.$t->name.'</a>';
		} else { 
			return $t->name; 
		}
	}
}

function ebor_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
 
add_filter( 'comment_form_fields', 'ebor_move_comment_field_to_bottom' );

/**
 * Add additional styling options to TinyMCE
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_mce_buttons_2') )){
	function ebor_mce_buttons_2( $buttons ) {
	    array_unshift( $buttons, 'styleselect' );
	    return $buttons;
	}
	add_filter( 'mce_buttons_2', 'ebor_mce_buttons_2' );
}


/**
 * Add additional styling options to TinyMCE
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_mce_before_init') )){
	function ebor_mce_before_init( $settings ) {
	    $style_formats = array(
    		array(
				'title'	=> 'Link Styles',
				'items'	=> array(
			    	array(
			    		'title' => 'Button',
			    		'selector' => 'a',
			    		'classes' => 'button',
			    	),
			    	array(
			    		'title' => 'Arrow',
			    		'selector' => 'a',
			    		'classes' => 'arrow',
			    	)
				)
	    	),
	    	array(
	    		'title'	=> 'Text Styles',
	    		'items'	=> array(
	    	    	array(
	    	    		'title' => 'Heading',
	    	    		'selector' => '*',
	    	    		'classes' => 'header',
	    	    	),
	    	    	array(
	    	    		'title' => 'Large Paragraph',
	    	    		'selector' => '*',
	    	    		'classes' => 'large',
	    	    	),
	    		)
	    	),
	    );
	    $settings['style_formats'] = json_encode( $style_formats );
	    return $settings;
	}
	add_filter( 'tiny_mce_before_init', 'ebor_mce_before_init' );
}