<?php 

/**
 * Build theme metaboxes
 * Uses the cmb metaboxes class found in the ebor framework plugin
 * More details here: https://github.com/WebDevStudios/Custom-Metaboxes-and-Fields-for-WordPress
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_custom_metaboxes') )){
	function ebor_custom_metaboxes( $meta_boxes ) {
		
		$prefix 		= '_ebor_';
		$social_options = ebor_get_social_icons();

		foreach($social_options as $option){
			$new_social_options[$option] = str_replace('fa-', '', $option);
		}

		/**
		 * Social Icons for Team Members
		 */
		$meta_boxes[] = array(
			'id' => 'social_metabox',
			'title' => esc_html__('Team Member Details', 'belton'),
			'object_types' => array('team'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => esc_html__('Job Title', 'belton'),
					'desc' => '(Optional) Enter a Job Title for this Team Member',
					'id'   => $prefix . 'the_job_title',
					'type' => 'text',
				),
				array(
				    'id'          => $prefix . 'team_social_icons',
				    'type'        => 'group',
				    'options'     => array(
				        'add_button'    => esc_html__( 'Add Another Icon', 'belton' ),
				        'remove_button' => esc_html__( 'Remove Icon', 'belton' ),
				        'sortable'      => true
				    ),
				    'fields' => array(
						array(
							'name' => 'Social Icon',
							'desc' => 'What icon would you like for this team members first social profile?',
							'id' => $prefix . 'social_icon',
							'type' => 'select',
							'options' => $new_social_options
						),
						array(
							'name' => esc_html__('URL for Social Icon', 'belton'),
							'desc' => esc_html__("Enter the URL for Social Icon 1 e.g www.google.com", 'belton'),
							'id'   => $prefix . 'social_icon_url',
							'type' => 'text'
						),
				    ),
				),
			)
		);

		$meta_boxes[] = array(
			'id'           => 'portfolio_layout_metabox',
			'title'        => esc_html__('Portfolio Item Layout Options', 'belton'),
			'object_types' => array('portfolio'), // post type
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
			'fields'       => array(
				array(
					'name'        => 'Project Orientation',
					'id'          => $prefix . 'portfolio_layout',
					'type'        => 'select',
					'options'     => array_flip( ebor_get_portfolio_single_layouts() ),
					'default'     => 'slideshow',
				),
				array(
					'name' => esc_html__('Featured Content Images', 'belton' ),
					'desc' => esc_html__('Drag & Drop to Reorder', 'belton' ),
					'id'   => $prefix . 'gallery_images',
					'type' => 'file_list',
				),
				array(
				    'id'          => $prefix . 'meta_repeat_group',
				    'type'        => 'group',
				    'name' 		  => esc_html__('Primary Project Information', 'belton' ),
				    'description' => esc_html__( 'Meta Titles & Descriptions', 'belton' ),
				    'options'     => array(
				        'add_button'    => esc_html__( 'Add Another Entry', 'belton' ),
				        'remove_button' => esc_html__( 'Remove Entry', 'belton' ),
				        'sortable'      => true, // beta
				    ),
				    'fields'       => array(
						array(
							'name' => esc_html__('Additional Item Title', 'belton'),
							'desc' => esc_html__("Title of your Additional Meta", 'belton'),
							'id'   => $prefix . 'the_additional_title',
							'type' => 'text'
						),
						array(
							'name' => esc_html__('Additional Item Detail', 'belton'),
							'desc' => esc_html__("Detail of your Additional Meta", 'belton'),
							'id'   => $prefix . 'the_additional_detail',
							'type' => 'text'
						),
				    ),
				),
				array(
					'name'    => 'Secondary Project Information',
					'desc'    => 'Shown in the Minimal slideshow layout only',
					'id'      => $prefix . 'secondary_portfolio_meta',
					'type'    => 'wysiwyg'
				)
			)
		);

		/**
		 * Post & Portfolio Header Images
		 */
		$meta_boxes[] = array(
			'id' => 'post_header_metabox',
			'title' => esc_html__('Page Overrides', 'belton'),
			'object_types' => array('page', 'portfolio', 'team', 'post' ), // post type
			'context' => 'normal',
			'priority' => 'low',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
				    'name'             => 'Header Style Overrides',
				    'desc'             => 'Select a header style to use on this page only',
				    'id'               => $prefix . 'header_style',
				    'type'             => 'select',
				    'show_option_none' => false,
				    'default'          => 'no-override',
				    'options'          => array(
				    	'no-override'  => 'Do Not Override',
				    	'dark-logo-transparent' => 'Dark Logo + Transparent Header BG',
				    ),
				),
			)
		);

		return $meta_boxes;
		
	}
	add_filter( 'cmb2_meta_boxes', 'ebor_custom_metaboxes' );
}