<?php 

/**
 * Build theme options
 * Uses the Ebor_Options class found in the ebor-framework plugin
 * Panels are WP 4.0+!!!
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if( class_exists('Ebor_Options') ){
	
	$social_options = array_keys(ebor_get_icons());
	$ebor_options   = new Ebor_Options;
	$theme          = wp_get_theme();
	$theme_name     = $theme->get( 'Name' );
	$yesNo          = array('yes' => 'Yes', 'no' => 'No');

	foreach( $social_options as $social_option ){
		$final_social_options[$social_option] = str_replace('fa-', '', $social_option);
	}

	/**
	 * Colour settings
	 */
	$ebor_options->add_setting('color', 'body_text', 'Body Text Colour', 'colors', '#666666', 1);
	$ebor_options->add_setting('color', 'preloader_background', 'Preloader Background Colour', 'colors', '#ffffff', 2);
	$ebor_options->add_setting('color', 'preloader_text', 'Preloader Text Colour', 'colors', '#555555', 3);
	$ebor_options->add_setting('color', 'navbar_background', 'Nav Background Colour', 'colors', '#ffffff', 4);
	$ebor_options->add_setting('color', 'strong_text', 'Strong Text Colour', 'colors', '#555555', 5);
	$ebor_options->add_setting('color', 'link_colour', 'Link Colour', 'colors', '#2b2b2b', 5);
	$ebor_options->add_setting('color', 'white_text', 'White Text Colour', 'colors', '#ffffff', 5);	
	$ebor_options->add_setting('color', 'heading_text', 'Heading Colour', 'colors', '#2b2b2b', 5);	
	$ebor_options->add_setting('color', 'footer_background', 'Footer Background Colour', 'colors', '#111111', 5);
	$ebor_options->add_setting('color', 'footer_text', 'Footer Content Colour', 'colors', '#ffffff', 5);
	$ebor_options->add_setting('color', 'dark_section_background', 'Dark Section Background Colour', 'colors', '#000000', 5);
	$ebor_options->add_setting('color', 'white_section_background', 'White Section Background Colour', 'colors', '#ffffff', 5);
	$ebor_options->add_setting('color', 'sticky_post_border', 'Sticky Post Border Colour', 'colors', '#cc0000', 5);
	
	$ebor_options->add_panel( $theme_name . ': Header Settings', 215, 'All of the controls in this section directly relate to the header and logos of ' . $theme_name);
	
	/**
	 * Header settings
	 */
	$ebor_options->add_section('logo_settings_section', 'Logo Settings', 10, $theme_name . ': Header Settings');
	
	//Logo Options
	$ebor_options->add_setting('image', 'theme_logo', 'Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/bg-logo-black.png', 5);
	$ebor_options->add_setting('image', 'theme_logo_light', 'Light Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/images/bg-logo.png', 5);

	//header Icons
	$ebor_options->add_section('header_social_section', 'Social Settings', 10, $theme_name . ': Header Settings');
	for( $i = 1; $i < 6; $i++ ){
		$ebor_options->add_setting('select', 'header_social_icon_' . $i, 'Header Social Icon ' . $i, 'header_social_section', 'none', 20 + $i + $i, $final_social_options);
		$ebor_options->add_setting('input', 'header_social_url_' . $i, 'Header Social URL ' . $i, 'header_social_section', '', 21 + $i + $i);
	}

	/**
	 * All Portfolio Settings
	 */
	$ebor_options->add_panel( $theme_name . ': Portfolio Settings', 220, 'All of the controls in this section directly relate to the control of Portfolio items within ' . $theme_name);
	
	/**
	 * Portfolio Archive settings
	 */
	$ebor_options->add_section('portfolio_archive_section', 'Portfolio Archive Settings', 15, $theme_name . ': Portfolio Settings');
	$ebor_options->add_setting('input', 'portfolio_title', 'Portfolio Title', 'portfolio_archive_section', 'Our full-service creative agency delivers innovation for inspiring companies', 10);
	$ebor_options->add_setting('input', 'portfolio_subtitle', 'Portfolio Subtitle', 'portfolio_archive_section', 'Portfolio', 15);

	/**
	 * All Team Settings
	 */
	$ebor_options->add_panel( $theme_name . ': Team Settings', 220, 'All of the controls in this section directly relate to the control of Team items within ' . $theme_name);
	
	/**
	 * Team Archive settings
	 */
	$ebor_options->add_section('team_archive_section', 'Team Archive Settings', 15, $theme_name . ': Team Settings');
	$ebor_options->add_setting('input', 'team_title', 'Team Title', 'team_archive_section', 'The Team', 10);
	
	/**
	 * All Team Settings
	 */
	$ebor_options->add_panel( $theme_name . ': Site Settings', 210, 'All of the controls in this section relate to various elements of ' . $theme_name);

	/**
	 * Preloader settings
	 */
	$ebor_options->add_section('preloader_section', 'Preloader Settings', 15, $theme_name . ': Site Settings');
	$ebor_options->add_setting('select', 'enable_preloader', 'Enable Preloader?', 'preloader_section', 'no', 5, $yesNo);
	$ebor_options->add_setting('input', 'preloader_text', 'loading', 'preloader_section', 'loading', 10);

	/**
	 * Typography settings
	 */
	$ebor_options->add_section('typography_section', 'Typography Settings', 15, $theme_name . ': Site Settings');
	$ebor_options->add_setting('input', 'google_font_string', 'Google Font URL Loading Parameters (Oswald:400,600,700|Amiri:400,600|Lato:400,600 - Default)', 'typography_section', 'Oswald:400,600,700|Amiri:400,600|Lato:400,600', 35);
	$ebor_options->add_setting('input', 'body_font', 'Body Font Name (Amiri Default)', 'typography_section', 'Amiri', 3);
	$ebor_options->add_setting('input', 'heading_font', 'Heading Font Name (Oswald Default)', 'typography_section', 'Oswald', 5);

	
	/**
	 * Footer settings
	 */
	$ebor_options->add_panel( $theme_name . ': Footer Settings', 245, 'All of the controls in this section directly relate to the control of footer design within ' . $theme_name);
	$ebor_options->add_section('footer_social_settings_section', 'Footer Social Settings', 20, $theme_name . ': Footer Settings');
	
	$ebor_options->add_section('footer_settings_section', 'Footer Settings', 30, $theme_name . ': Footer Settings');
	
	$ebor_options->add_setting('textarea', 'footer_copyright', 'Copyright Message', 'footer_settings_section', '*copy* *current_year* Belton Theme', 20);
	$ebor_options->add_setting('textarea', 'footer_copyright_right', 'Copyright Message', 'footer_settings_section', 'Made with <i class="fa fa-heart"></i> by <a href="http://www.tommusrhodus.com">TommusRhodus</a>.', 25);

}