<?php 


/**
 * Fonts URL
 * Load google font families for this theme
 * @since version 1.0
 * @author TommusRhodus
 */ 
if(!( function_exists('ebor_fonts_url') )){
	function ebor_fonts_url(){
	    $font_url = '';

	    /**
	     * Translators: If there are characters in your language that are not supported
	     * by chosen font(s), translate this to 'off'. Do not translate into your own language.
	     */
	    if ( 'off' !== _x( 'on', 'Google font: on or off', 'belton' ) ) {
	        $font_url = add_query_arg( 'family', urlencode( str_replace('+', ' ', get_option('google_font_string','Oswald:400,600,700|Amiri:400,600|Lato:400,600')) ), "//fonts.googleapis.com/css" );
	    }
	    return $font_url;
	}
}

/**
 * Ebor Load Scripts
 * Properly Enqueues Scripts & Styles for the theme
 * @since version 1.0
 * @author TommusRhodus
 */ 
if(!( function_exists('ebor_load_scripts') )){
	function ebor_load_scripts() {
		
		$theme_data = wp_get_theme();
		$version    = $theme_data->get( 'Version' );
		
		//Enqueue Styles
		wp_enqueue_style( 
			'ebor-google-font', 
			ebor_fonts_url(), 
			array(), 
			$version 
		);
		
		wp_enqueue_style( 
			'bootstrap', 
			get_theme_file_uri( 'style/css/bootstrap.min.css' ), 
			array(), 
			$version 
		);
		
		wp_enqueue_style( 
			'flexslider-css', 
			get_theme_file_uri( 'style/css/flexslider.css' ), 
			array(), 
			$version 
		);

		wp_enqueue_style( 
			'fancybox-css', 
			get_theme_file_uri( 'style/css/jquery.fancybox.css' ), 
			array(), 
			$version 
		);
		
		wp_enqueue_style( 
			'font-awesome', 
			get_theme_file_uri( 'style/css/font-awesome.min.css' ), 
			array(), 
			$version 
		);
		
		wp_enqueue_style( 
			'ebor-style', 
			get_stylesheet_uri(), 
			array(), 
			$version 
		);
		
		//Enqueue Scripts
		wp_enqueue_script( 
			'bootstrap', 
			get_theme_file_uri( 'style/js/bootstrap.min.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-easing', 
			get_theme_file_uri( 'style/js/jquery-easing.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-bbq', 
			get_theme_file_uri( 'style/js/bbq.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'fancybox', 
			get_theme_file_uri( 'style/js/jquery.fancybox.pack.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'flexslider', 
			get_theme_file_uri( 'style/js/jquery.flexslider-min.js' ), 
			array('jquery'), 
			$version, 
			true  
		);

		wp_enqueue_script( 
			'goodshare', 
			get_theme_file_uri( 'style/js/goodshare.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-isotope', 
			get_theme_file_uri( 'style/js/jquery.isotope2.min.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-touch-swipe', 
			get_theme_file_uri( 'style/js/jquery.touchSwipe.min.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-packery-mode', 
			get_theme_file_uri( 'style/js/packery-mode.pkgd.min.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		wp_enqueue_script( 
			'ebor-scripts', 
			get_theme_file_uri( 'style/js/main.js' ), 
			array('jquery'), 
			$version, 
			true  
		);
		
		//Enqueue Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		$body_text = get_option( 'body_text', '#666666' );
		$preloader_background = get_option( 'preloader_background', '#ffffff' );
		$preloader_text = get_option( 'preloader_text', '#555555' );
		$navbar_background = get_option( 'navbar_background', '#ffffff' );
		$strong_text = get_option( 'strong_text', '#555555' );
		$link_colour = get_option( 'link_colour', '#2b2b2b' );		
		$white_text = get_option( 'white_text', '#ffffff' );		
		$heading_text = get_option( 'heading_text', '#2b2b2b' );			
		$footer_background = get_option( 'footer_background', '#111111' );			
		$footer_text = get_option( 'footer_text', '#ffffff' );
		$dark_section_background = get_option( 'dark_section_background', '#000000' );		
		$white_section_background = get_option( 'white_section_background', '#ffffff' );
		$body_font = get_option( 'body_font', 'Amiri' );
		$heading_font = get_option( 'heading_font', 'Oswald' );			
		$sticky_post_border = get_option( 'sticky_post_border', '#cc0000' );

		$skin = '
			#preloader {
				background: '.sanitize_hex_color($preloader_background).';
			}
			#status {
				color: '.sanitize_hex_color($preloader_text).' !important;
			}
			.nav-bar {
				background-color: '.sanitize_hex_color($navbar_background).';
			}
			#nav-wrapper {
				background: '.sanitize_hex_color($navbar_background).';
			}
			body {
				font-family: '. $body_font .';
				color: '.sanitize_hex_color($body_text).';
			}
			p strong {
				color: '.sanitize_hex_color($strong_text).';
			}
			a, a:hover, a:focus, p a {
				color: '.sanitize_hex_color($link_colour).';
			}
			.white-text p a, .intro p a, .white-text h1, .white-text h2, .white-text h3, .white-text h4, .white-text h5, .white-text h6, .custom-caption, .white-text ul, .white-text ol, footer p strong, footer a:hover {
				color: '.sanitize_hex_color($white_text).';
			}
			.numbers, h1, h2, h3, h4, h5, h6 {
				font-family: '. $heading_font .';
				color: '.sanitize_hex_color($heading_text).';
			}
			#footer {
				background: '.sanitize_hex_color($footer_background).';
			}
			footer .numbers, footer h1, footer h2, footer h3, footer h4, footer h5, footer h6, footer p, footer a, footer {
				color: '.sanitize_hex_color($footer_text).';
			}
			section {
				background: '.sanitize_hex_color($dark_section_background).';
			}
			section.white {
				background: '.sanitize_hex_color($white_section_background).';
			}
			.sticky .greyed {
			    border: 2px solid '.sanitize_hex_color($sticky_post_border).';
			}
		';
		
		wp_add_inline_style( 'ebor-style', $skin );
	
	}
	add_action('wp_enqueue_scripts', 'ebor_load_scripts', 110);
}

if(!( function_exists('ebor_admin_load_scripts') )){
	function ebor_admin_load_scripts(){
	
		wp_enqueue_style( 'ebor-theme-admin-css', EBOR_THEME_DIRECTORY . 'admin/ebor-theme-admin.css' );
		wp_enqueue_style( 'ebor-icons', get_theme_file_uri( 'style/css/font-awesome.min.css' ) );	
		wp_enqueue_script( 'ebor-theme-admin-js', EBOR_THEME_DIRECTORY . 'admin/ebor-theme-admin.js', array('jquery'), false, true );
		
	}
	add_action('admin_enqueue_scripts', 'ebor_admin_load_scripts', 200);
}